@@ -37,7 +37,7 @@ default_channels = "irc://chat.freenode.net/#commits"
 # No user-serviceable parts below this line:
 #
 
-version = "1.15"
+version = "1.17"
 
 import os, sys, commands, socket, urllib, subprocess, locale
 from pipes import quote as shellquote
@@ -47,7 +47,7 @@ except ImportError:
     import json
 
 def do(command):
-    return unicode(commands.getstatusoutput(command)[1], locale.getpreferredencoding() or 'UTF-8')
+    return unicode(commands.getstatusoutput(command)[1], locale.getlocale()[1] or 'UTF-8').encode(locale.getlocale()[1] or 'UTF-8')
 
 class Commit:
     def __init__(self, extractor, commit):
@@ -264,7 +264,7 @@ class GitExtractor(GenericExtractor):
         # conventionally supposed to be a summary of the commit.  Under
         # other VCSes a different choice may be appropriate.
         metainfo = do("git log -1 '--pretty=format:%an <%ae>|%s' " + shellquote(commit.commit))
-        (commit.author, commit.logmsg) = metainfo.split("|")
+        (commit.author, _, commit.logmsg) = metainfo.partition("|")
         commit.mail = commit.author.split()[-1].strip("<>")
         # This discards the part of the author's address after @.
         # Might be be nice to ship the full email address, if not
